import router from './router'
import { useNProgress } from '@/hooks/web/useNProgress'
import { useTitle } from '@/hooks/web/useTitle'
import { getToken, getEnterpriseToken, removeToken } from '@/utils/auth'
import { useDictStore } from '@/store/dict'

const { start, done } = useNProgress()
// loginType：1.enterprise: 企业路由
//            2.personal: 个人路由
//            3.personalCommon: 无需登录也能访问的页面，但登录企业不能访问
// 路由守卫
router.beforeEach(async (to, from, next) => {
  start()
  // loadStart()
  if (getToken()) {
    if (to.path === '/login') {
      if (getEnterpriseToken()) next({ path: '/enterprise' }) // 已登录企业
      else next({ path: '/recruitHome' }) // 已登录个人账号
    } else {
      // 获取字典信息
      const dictStore = useDictStore()
      dictStore.getDictTypeData()
      
      const type = localStorage.getItem('loginType')
      // 判断企业路由和个人路由，防止互串
      if (!type) { removeToken(); next(`/login?redirect=${to.fullPath}`) }
      else if (to.meta?.loginType === 'common') next()
      else if (type === 'enterprise' && to.meta?.loginType === 'personalCommon') next({ path: `/${type}` }) // 企业端不能访问任何个人端路由
      else if (type === 'personal' && to.meta?.loginType === 'personalCommon') next()
      else if (to.meta?.loginType === type) next()
      else next({ path: `/${type}` })
      // next()
    }
  } else {
    if (to.meta?.loginType === 'personalCommon' || to.meta?.loginType === 'common') { // 路由不重定向
      next()
    } else {
      next(`/login?redirect=${to.fullPath}`) // 否则全部重定向到登录页
    }
  }
})

router.afterEach((to) => {
  useTitle(to?.meta?.title)
  done() // 结束Progress
  // loadDone()
})