// 企业路由信息
import Layout from '@/layout/enterprise.vue'

const enterprise = [
  {
    path: '/enterprise', // 企业账号登录时，缺省进去企业路由，防止用户在地址栏直接输入地址访问其他页面（不可删，permission中用到）
    show: true,
    redirect: '/recruit/enterprise',
  },
  {
    path: '/recruit/enterprise',
    show: true,
    redirect: '/recruit/enterprise/resumeManagement/talentPool',
  },
  {
    path: '/recruit/enterprise/resumeManagement',
    redirect: '/recruit/enterprise/resumeManagement/talentPool',
    component: Layout,
    name: 'Resume Management',
    meta: {
      title: '简历管理',
      enName: 'Resume Management',
      icon: 'mdi-account-settings-outline'
    },
    children: [
      {
        path: '/recruit/enterprise/resumeManagement/talentPool',
        meta: {
          title: '人才库',
          enName: 'Talent Pool'
        },
        component: () => import('@/views/recruit/enterprise/resumeManagement/talentPool/index.vue')
      },
      {
        path: '/recruit/enterprise/resumeManagement/talentPool/details/:id',
        show: true, // 侧边栏不展示
        component: () => import('@/views/recruit/enterprise/resumeManagement/talentPool/components/details'),
        name: 'talentPoolDetails',
        meta: {
          title: '人才详情',
          hideSide: true
        }
      },
      {
        path: '/recruit/enterprise/resumeManagement/elite',
        meta: {
          title: '精英人才',
          enName: 'Elite talents'
        },
        component: () => import('@/views/recruit/enterprise/resumeManagement/elite/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/position',
    component: Layout,
    name: 'jobManagement',
    meta: {
      title: '职位管理',
      enName: 'Job Management',
      icon: 'mdi-format-list-bulleted-square'
    },
    children: [
      {
        path: '/recruit/enterprise/position',
        name: 'recruitEnterprisePosition',
        meta: {
          title: '职位列表',
          enName: 'Job list'
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/index.vue')
      },
      {
        path: '/recruit/enterprise/position/add',
        show: true,
        meta: {
          title: '新增职位'
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/components/add.vue')
      },
      {
        path: '/recruit/enterprise/position/edit',
        show: true,
        meta: {
          title: '职位编辑'
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/components/add.vue')
      },
      {
        path: '/recruit/enterprise/position/details/:id',
        show: true,
        meta: {
          title: '职位详情',
          hideSide: true
        },
        component: () => import('@/views/recruit/enterprise/positionManagement/components/details.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/chatTools',
    component: Layout,
    name: 'chatTools',
    meta: {
      title: '聊天工具',
      enName: 'Chat Tools',
      icon: 'mdi-bell-outline'
    },
    children: [
      {
        path: '/recruit/enterprise/chatTools',
        show: true,
        component: () => import('@/views/recruit/enterprise/chatTools/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/interviewManagement',
    component: Layout,
    name: 'interviewManagement',
    meta: {
      title: '面试管理',
      enName: 'Interview management',
      icon: 'mdi-account-multiple-check'
    },
    children: [
      {
        path: '/recruit/enterprise/interviewManagement',
        show: true,
        component: () => import('@/views/recruit/enterprise/interviewManagement/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/statistics/overallAnalysis',
    component: Layout,
    name: 'enterpriseStatistics',
    meta: {
      title: '统计分析',
      enName: 'Statistics',
      icon: 'mdi-chart-arc'
    },
    children: [
      {
        path: '/recruit/enterprise/statistics/overallAnalysis',
        show: true,
        component: () => import('@/views/recruit/enterprise/statistics/overallAnalysis.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/informationManagement',
    component: Layout,
    redirect: '/recruit/enterprise/informationManagement/informationSettings',
    name: 'informationManagement',
    meta: {
      title: '信息管理',
      enName: 'Information Management',
      icon: 'mdi-tune'
    },
    children: [
      {
        path: '/recruit/enterprise/informationManagement/informationSettings',
        meta: {
          title: '企业信息设置',
          isAdmin: true,
          enName: 'Enterprise Information Settings'
        },
        component: () => import('@/views/recruit/enterprise/informationManagement/informationSettings.vue')
      },
      {
        path: '/recruit/enterprise/informationSettings',
        meta: {
          title: '个人信息设置',
          enName: 'Personal information settings'
        },
        component: () => import('@/views/recruit/enterprise/informationSetting/index.vue')
      }
    ]
  },
  {
    path: '/recruit/enterprise/systemManagement',
    component: Layout,
    redirect: '/recruit/enterprise/systemManagement/userManagement',
    name: 'systemManagement',
    meta: {
      title: '系统管理',
      enName: 'system Management',
      icon: 'mdi-cog-outline',
      isAdmin: true // 企业管理员菜单
    },
    children: [
      {
        path: '/recruit/enterprise/systemManagement/groupAccount',
        meta: {
          title: '集团账户',
          enName: 'Group Account '
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/groupAccount/index.vue')
      },
      {
        path: '/recruit/enterprise/systemManagement/groupAccount/invite/:type',
        show: true,
        meta: {
          hideSide: true,
          title: '邀请',
          enName: 'Invite'
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/groupAccount/invite.vue')
      },
      // {
      //   path: '/recruit/enterprise/systemManagement/userManagement',
      //   meta: {
      //     title: '用户管理',
      //     enName: 'User Management '
      //   },
      //   component: () => import('@/views/recruit/enterprise/systemManagement/userManagement/index.vue')
      // },
      {
        path: '/recruit/enterprise/systemManagement/postManagement',
        meta: {
          title: '岗位管理',
          enName: 'Post Management '
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/postManagement/index.vue')
      },
      {
        path: '/recruit/enterprise/systemManagement/postManagement/add',
        show: true,
        meta: {
          title: '新增岗位'
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/postManagement/save.vue')
      },
      {
        path: '/recruit/enterprise/systemManagement/postManagement/edit',
        show: true,
        meta: {
          title: '岗位编辑'
        },
        component: () => import('@/views/recruit/enterprise/systemManagement/postManagement/save.vue')
      },
    ]
  },
  {
    path: '/recruit/enterprise/memberCenter',
    component: Layout,
    redirect: '/recruit/enterprise/memberCenter/myMembers',
    name: 'enterpriseMemberCenter',
    meta: {
      title: '会员中心',
      enName: 'system Management',
      icon: 'mdi-account',
      // isAdmin: true // 企业管理员菜单
    },
    children: [
      {
        path: '/recruit/enterprise/memberCenter/myMembers',
        meta: {
          title: '我的会员',
          enName: 'My Members'
        },
        component: () => import('@/views/recruit/enterprise/memberCenter/myMembers/index.vue')
      },
      // {
      //   path: '/recruit/enterprise/memberCenter/myAccount',
      //   meta: {
      //     title: '我的账户',
      //     enName: 'Account '
      //   },
      //   component: () => import('@/views/recruit/enterprise/memberCenter/myAccount/index.vue')
      // },
      {
        path: '/recruit/enterprise/memberCenter/tradingOrder',
        meta: {
          title: '我的订单',
          enName: 'tradingOrder '
        },
        component: () => import('@/views/recruit/enterprise/memberCenter/tradingOrder/index.vue')
      },
      {
        path: '/recruit/enterprise/memberCenter/invoiceHeader',
        meta: {
          title: '发票抬头管理',
          enName: 'InvoiceHeaderManagement '
        },
        component: () => import('@/views/recruit/enterprise/memberCenter/invoice/header.vue')
      }
    ]
  },
  // {
  //   path: '/recruit/enterprise/enterpriseCenter',
  //   component: Layout,
  //   name: 'enterpriseCenter',
  //   show: true,
  //   redirect: '/recruit/enterprise/enterpriseCenter',
  //   meta: {
  //     title: '企业中心'
  //   },
  //   children: [
  //     {
  //       path: '/recruit/enterprise/enterpriseCenter',
  //       show: true,
  //       component: () => import('@/views/recruit/enterprise/enterpriseCenter/index.vue'),
  //       meta: {
  //         title: '企业中心',
  //         hideSide: true
  //       }
  //     }
  //   ]
  // },
  {
    path: '/recruit/enterprise/purchasePackage',
    component: Layout,
    name: 'enterprisePurchasePackage',
    show: true,
    meta: {
      title: '购买套餐',
    },
    children: [
      {
        path: '/recruit/enterprise/purchasePackage',
        component: () => import('@/views/recruit/enterprise/purchasePackage/index'),
        meta: {
          title: '购买套餐',
          hideSide: true
        },
      }
    ]
  },
]
export default enterprise